@@ -49,7 +49,7 @@ class ConsumerMixin(object):
         .. code-block:: python
 
             class Worker(ConsumerMixin):
-                task_queue = Queue('tasks', Exchange('tasks'), 'tasks'))
+                task_queue = Queue('tasks', Exchange('tasks'), 'tasks')
 
                 def __init__(self, connection):
                     self.connection = None
