@@ -1,8 +1,10 @@
-from __future__ import absolute_import
+"""AMQP Management API utilities."""
+from __future__ import absolute_import, unicode_literals
 
 
 def get_manager(client, hostname=None, port=None, userid=None,
                 password=None):
+    """Get pyrabbit manager."""
     import pyrabbit
     opt = client.transport_options.get
 
